unit RosiDBDesignEditors_Reg;

{<
  RosiDBDesignEditors_Reg is unit for registration of design time dialog
  for all Rosi components.

  Updated version compatible with Delphi2010+.
  Full functional demo.
  @author(Rosinsky Software - <http://www.rosinsky.cz/delphi>)
  @created(May 2006)
}

interface

uses
  Windows, Messages, SysUtils, Variants, Classes, Graphics, Controls,
  Forms, Dialogs, StdCtrls, ShlObj,
  DesignIntf, DesignEditors, ColnEdit,
  rDBGrid, PropSaveMain, rDBRecView, rImprovedComps;

type
  { @exclude }
  TPropSave_Editor = class(TComponentEditor)
  public
    procedure ExecuteVerb(Index: Integer); override;
    function GetVerb(Index: Integer): string; override;
    function GetVerbCount: Integer; override;
  end;

  { @exclude }
  TrGroupBox_Editor = class(TComponentEditor)
  public
    procedure ExecuteVerb(Index: Integer); override;
    function GetVerb(Index: Integer): string; override;
    function GetVerbCount: Integer; override;
  end;

  { @exclude }
  TrDBGrid_Editor = class(TComponentEditor)
  public
    procedure ExecuteVerb(Index: Integer); override;
    function GetVerb(Index: Integer): string; override;
    function GetVerbCount: Integer; override;
  end;

  { @exclude }
  TrDBRecView_Editor = class(TComponentEditor)
  public
    procedure ExecuteVerb(Index: Integer); override;
    function GetVerb(Index: Integer): string; override;
    function GetVerbCount: Integer; override;
  end;

  { @exclude }
  TDBTrackSource_Editor = class(TComponentEditor)
  public
    procedure ExecuteVerb(Index: Integer); override;
    function GetVerb(Index: Integer): string; override;
    function GetVerbCount: Integer; override;
  end;

  { @exclude }
  TDBTrackTarget_Editor = class(TComponentEditor)
  public
    procedure ExecuteVerb(Index: Integer); override;
    function GetVerb(Index: Integer): string; override;
    function GetVerbCount: Integer; override;
  end;

procedure Register; {< @exclude }

implementation

uses rDBGrid_DTEdit, PropSave_DTEdit, rDBRecView_DTEdit, rGroupBox_DTEdit,
  DBTrackTool, DBTrackSource_DTEdit, DBTrackTarget_DTEdit;

procedure Register;
begin
  ForceDemandLoadState(dlDisable);
  RegisterComponentEditor(TCustomPropSave, TPropSave_Editor);
  RegisterComponentEditor(TPropSaveMain, TPropSave_Editor);
  RegisterComponentEditor(TrDBGrid, TrDBGrid_Editor);
  RegisterComponentEditor(TrDBRecView, TrDBRecView_Editor);
  RegisterComponentEditor(TrGroupBox, TrGroupBox_Editor);
  RegisterComponentEditor(TTrackRecSource, TDBTrackSource_Editor);
  RegisterComponentEditor(TTrackRecTarget, TDBTrackTarget_Editor);
end;

function TPropSave_Editor.GetVerbCount: Integer;
begin
  Result:= inherited GetVerbCount + 1;
end;

function TPropSave_Editor.GetVerb(Index: Integer): string;
var
  I: Integer;
begin
  I:= inherited GetVerbCount;
  if Index < I then
    Result:= inherited GetVerb(Index)
  else
    case Index - I of
      0:
        Result:='PropertySaver Editor...';
    end;
end;

procedure TPropSave_Editor.ExecuteVerb(Index: Integer);
var
  I: Integer;
begin
  I:= inherited GetVerbCount;
  if Index < I then
    inherited
  else
  begin
    case Index - I of
      0:
        if ShowPropertySaverEditor(Component) then
          Designer.Modified;
    end;
  end;
end;

function TrGroupBox_Editor.GetVerbCount: Integer;
begin
  Result:= inherited GetVerbCount + 1;
end;

function TrGroupBox_Editor.GetVerb(Index: Integer): string;
var
  I: Integer;
begin
  I:= inherited GetVerbCount;
  if Index < I then
    Result:= inherited GetVerb(Index)
  else
    case Index - I of
      0:
        Result:='rGroupBox Editor...';
    end;
end;

procedure TrGroupBox_Editor.ExecuteVerb(Index: Integer);
var
  I: Integer;
begin
  I:= inherited GetVerbCount;
  if Index < I then
    inherited
  else
  begin
    case Index - I of
      0:
        if ShowrGroupBoxEditor(Component) then
          Designer.Modified;
    end;
  end;
end;

function TrDBGrid_Editor.GetVerbCount: Integer;
begin
  Result:= inherited GetVerbCount + 2;
end;

function TrDBGrid_Editor.GetVerb(Index: Integer): string;
var
  I: Integer;
begin
  I:= inherited GetVerbCount;
  if Index < I then
    Result:= inherited GetVerb(Index)
  else
    case Index - I of
      0:
        Result:='rDBGrid Editor...';
      1:
        Result:='Columns editor';
    end;
end;

procedure TrDBGrid_Editor.ExecuteVerb(Index: Integer);
var
  I: Integer;
begin
  I:= inherited GetVerbCount;
  if Index < I then
    inherited
  else
  begin
    case Index - I of
      0:
        if ShowrDBGridEditor(Component) then
          Designer.Modified;
      1:
        ShowCollectionEditor(Designer, Component, TrDBGrid(Component).Columns, 'Columns');
    end;
  end;
end;

function TrDBRecView_Editor.GetVerbCount: Integer;
begin
  Result:= inherited GetVerbCount + 1;
end;

function TrDBRecView_Editor.GetVerb(Index: Integer): string;
var
  I: Integer;
begin
  I:= inherited GetVerbCount;
  if Index < I then
    Result:= inherited GetVerb(Index)
  else
    case Index - I of
      0:
        Result:='rDBRecView Editor...';
    end;
end;

procedure TrDBRecView_Editor.ExecuteVerb(Index: Integer);
var
  I: Integer;
begin
  I:= inherited GetVerbCount;
  if Index < I then
    inherited
  else
  begin
    case Index - I of
      0:
        if ShowrDBRecViewEditor(Component) then
          Designer.Modified;
    end;
  end;
end;

function TDBTrackSource_Editor.GetVerbCount: Integer;
begin
  Result:= inherited GetVerbCount + 1;
end;

function TDBTrackSource_Editor.GetVerb(Index: Integer): string;
var
  I: Integer;
begin
  I:= inherited GetVerbCount;
  if Index < I then
    Result:= inherited GetVerb(Index)
  else
    case Index - I of
      0:
        Result:='DBTrackSource Editor...';
    end;
end;

procedure TDBTrackSource_Editor.ExecuteVerb(Index: Integer);
var
  I: Integer;
begin
  I:= inherited GetVerbCount;
  if Index < I then
    inherited
  else
  begin
    case Index - I of
      0:
        if ShowDBTrackSourceEditor(Component) then
          Designer.Modified;
    end;
  end;
end;

function TDBTrackTarget_Editor.GetVerbCount: Integer;
begin
  Result:= inherited GetVerbCount + 1;
end;

function TDBTrackTarget_Editor.GetVerb(Index: Integer): string;
var
  I: Integer;
begin
  I:= inherited GetVerbCount;
  if Index < I then
    Result:= inherited GetVerb(Index)
  else
    case Index - I of
      0:
        Result:='DBTrackTarget Editor...';
    end;
end;

procedure TDBTrackTarget_Editor.ExecuteVerb(Index: Integer);
var
  I: Integer;
begin
  I:= inherited GetVerbCount;
  if Index < I then
    inherited
  else
  begin
    case Index - I of
      0:
        if ShowDBTrackTargetEditor(Component) then
          Designer.Modified;
    end;
  end;
end;

end.
