unit f_checkRTF;

interface

uses
  Windows, Messages, SysUtils, Variants, Classes, Graphics, Controls, Forms,
  Dialogs, StdCtrls, ComCtrls, Buttons, ExtCtrls, PropSaveMain,
  Grids, ValEdit, rImprovedComps, rHTMLLabel, RTFReport2;

type
  TMain = class(TForm)
    OpenDlg: TOpenDialog;
    PropSaveFile1: TPropSaveFile;
    PropSaveMain1: TPropSaveMain;
    gbFiles: TrGroupBox;
    lb: TListBox;
    rGroupBox2: TrGroupBox;
    rGroupBox1: TrGroupBox;
    pc: TPageControl;
    TabSheet1: TTabSheet;
    tc: TTabControl;
    e: TMemo;
    TabSheet2: TTabSheet;
    vle: TValueListEditor;
    btDelSel: TrButton;
    btDelAll: TrButton;
    btCheckSel: TrButton;
    btCheckAll: TrButton;
    btClearThemeData: TrButton;
    chBackup: TCheckBox;
    RTFRep: TRTFReport2;
    sh: TrStringsHolder;
    chExtractInnerTags: TCheckBox;
    procedure tcChange(Sender: TObject);
    procedure FormClose(Sender: TObject; var Action: TCloseAction);
    procedure gbFilesDropFiles(Sender: TObject; X, Y: Integer);
    procedure btCheckSelClick(Sender: TObject);
    procedure btCheckAllClick(Sender: TObject);
    procedure btDelSelClick(Sender: TObject);
    procedure btDelAllClick(Sender: TObject);
    procedure OnAbort(Sender: TObject);
  private
    { Private declarations }
  public
    { Public declarations }
    Aborted: boolean;
    FReportFile: string;
    L: array of TStrings;
    procedure FreeAll;
    procedure LoadProcFile;
    procedure CheckTags;
    function ClearThemeData: boolean;
  end;

var
  Main: TMain;

implementation

{$R *.dfm}

uses rstring, rtool, rdlg;

procedure TMain.btCheckSelClick(Sender: TObject);
begin
  if (lb.ItemIndex < 0) or (lb.ItemIndex > lb.Items.Count - 1) then
    Exit;
  Aborted := false;
  FreeAll;
  pc.ActivePageIndex := 0;
  gbFiles.Enabled := false;
  try
    CheckTags;
    tcChange(nil);
    pc.ActivePageIndex := 1;
  finally
    gbFiles.Enabled := true;
  end;
end;

procedure TMain.btCheckAllClick(Sender: TObject);
var
  i: Integer;
begin
  Aborted := false;
  FreeAll;
  pc.ActivePageIndex := 0;
  gbFiles.Enabled := false;
  try
    for i := 0 to lb.Items.Count - 1 do
    begin
      lb.ItemIndex := i;
      if Aborted then
        Break;
      if Sender = btCheckAll then
        CheckTags
      else
      begin
        if ClearThemeData then
          vle.InsertRow(ExtractFileName(FReportFile), 'Theme data removed.', true);
      end;
    end;
    tcChange(nil);
    pc.ActivePageIndex := 1;
  finally
    gbFiles.Enabled := true;
  end;
end;

function TMain.ClearThemeData: boolean;
var
  RepStr: string;
  FS: TFileStream;
  i: Integer;
  AStr: AnsiString;
begin
  Result:=false;
  FReportFile := lb.Items[lb.ItemIndex];
  if chBackup.Checked then
    CopyFile(PChar(FReportFile), PChar(ChangeFileExt(FReportFile, '.bup')), false);

  // read report file to string
  try
    FS := TFileStream.Create(FReportFile, fmOpenRead + fmShareDenyNone);
    try
      SetLength(AStr, FS.Size);
      FS.Read(Pointer(AStr)^, FS.Size);
    finally
      FS.Free;
    end;
  except
    raise Exception.Create(Format(sFileOpenErr, [FReportFile]) + #13 + sFileOpenErr2);
  end;
  RepStr := string(AStr);

  i := AnsiPos('{\*\themedata', RepStr);
  if i > 0 then
  begin
    RepStr := copy(RepStr, 1, i - 1) + '}';
    Result:=true;
  end;
  AStr := AnsiString(RepStr);

  try
    FS := TFileStream.Create(FReportFile, fmCreate);
    try
      FS.Write(Pointer(AStr)^, Length(AStr));
    finally
      FS.Free;
    end;
  except
    raise Exception.Create(Format(sFileSaveErr, [FReportFile]) + #13 + sFileSaveErr2);
  end;
end;

procedure TMain.btDelAllClick(Sender: TObject);
begin
  lb.Items.Clear;
end;

procedure TMain.btDelSelClick(Sender: TObject);
var
  i: Integer;
begin
  for i := lb.Items.Count-1 downto 0 do
    if lb.Selected[i] then
      lb.Items.Delete(i);
end;

procedure TMain.FreeAll;
var
  i: Integer;
begin
  e.Lines.Clear;
  tc.Tabs.Clear;
  for i := 0 to High(L) do
    L[i].Free;
  SetLength(L, 0);
  if vle.Strings.Count>0 then
    for i := vle.RowCount - 1 downto 1 do
      vle.DeleteRow(i);
end;

procedure TMain.gbFilesDropFiles(Sender: TObject; X, Y: Integer);
var
  i: Integer;
begin
  for i := 0 to gbFiles.DropFilesCount - 1 do
    lb.Items.Add(gbFiles.DropFileNames[i]);
end;

procedure TMain.OnAbort(Sender: TObject);
begin
  Aborted := true;
end;

procedure TMain.LoadProcFile;
var
  i: Integer;
begin
  FReportFile := lb.Items[lb.ItemIndex];
  tc.Tabs.Add(ExtractFileName(FReportFile));
  i := tc.Tabs.Count;
  tc.TabIndex := i - 1;
  SetLength(L, i);
  L[i - 1] := TStringList.Create;
  RTFRep.ReportFile := FReportFile;
  RTFRep.ExtractCheckTags(L[i - 1], sh.Strings, chExtractInnerTags.Checked);
end;

procedure TMain.tcChange(Sender: TObject);
begin
  if tc.TabIndex>=0 then
    e.Lines.Assign(L[tc.TabIndex]);
end;

procedure TMain.FormClose(Sender: TObject; var Action: TCloseAction);
begin
  FreeAll;
end;

procedure TMain.CheckTags;
var
  i: Integer;
begin
  rdlg.ShowInfoEx('Processing...', self, OnAbort);
  try
    LoadProcFile;
    for i := 0 to sh.Strings.Count - 1 do
      vle.InsertRow(tc.Tabs[tc.TabIndex], sh.Strings[i], true);
  finally
    rdlg.ShowInfo('');
  end;
end;

end.
